==> nextcloud-27.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/et_EE.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "Uus tekstifail",
    "The file was uploaded" : "Fail laaditi üles",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Üleslaetud fail on suurem, kui php.ini failis määratud upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaetud fail on suurem, kui MAX_FILE_SIZE atribuut, mis seadistati HTML vormis",
    "The file was only partially uploaded" : "Fail laaditi üles ainult osaliselt",
    "No file was uploaded" : "Ühtegi faili ei latud üles",
    "Missing a temporary folder" : "Ajutine kausta on puudu",
    "Could not write file to disk" : "Faili kirjutamine kettale ebaõnnestus",
    "A PHP extension stopped the file upload" : "PHP laiendus peatas faili üleslaadimise",
    "No file uploaded or file size exceeds maximum of %s" : "Faili ei laaditud üles või selle suurus ületab maksimaalse %s",
    "Use current version" : "Kasuta praegust versiooni",
    "Use the saved version" : "Kasuta salvestatud versiooni",
    "Guest" : "Külaline",
    "guest" : "külaline",
    "Offline" : "Offline",
    "Saving …" : "Salvestamine …",
    "Saved" : "Salvestatud",
    "Unsaved changes" : "Salvestamata muutused",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Translate" : "Tõlgi",
    "to" : "saaja",
    "Replace" : "Asenda",
    "Detect language" : "Tuvasta keel",
    "Translation failed" : "Tõlkimine ebaõnnestus",
    "Unsupported image type" : "Pildi tüüp pole toetatud",
    "Undo" : "Tühista",
    "Headings" : "Pealkirjad",
    "Info" : "Info",
    "Warning" : "Hoiatus",
    "Edit" : "Redigeeri"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/et_EE.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "Uus tekstifail",
    "The file was uploaded" : "Fail laaditi üles",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Üleslaetud fail on suurem, kui php.ini failis määratud upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaetud fail on suurem, kui MAX_FILE_SIZE atribuut, mis seadistati HTML vormis",
    "The file was only partially uploaded" : "Fail laaditi üles ainult osaliselt",
    "No file was uploaded" : "Ühtegi faili ei latud üles",
    "Missing a temporary folder" : "Ajutine kausta on puudu",
    "Could not write file to disk" : "Faili kirjutamine kettale ebaõnnestus",
    "A PHP extension stopped the file upload" : "PHP laiendus peatas faili üleslaadimise",
    "No file uploaded or file size exceeds maximum of %s" : "Faili ei laaditud üles või selle suurus ületab maksimaalse %s",
    "Translate" : "Tõlgi",
    "Use current version" : "Kasuta praegust versiooni",
    "Use the saved version" : "Kasuta salvestatud versiooni",
    "Reload" : "Lae uuesti",
    "Guest" : "Külaline",
    "guest" : "külaline",
    "Offline" : "Offline",
    "Saving …" : "Salvestamine …",
    "Saved" : "Salvestatud",
    "Unsaved changes" : "Salvestamata muutused",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Cancel" : "Tühista",
    "URL" : "URL",
    "Cannot copy, please copy the link manually" : "Ei saa kopeerida, palun kopeeri link käsitsi",
    "to" : "saaja",
    "Replace" : "Asenda",
    "Detect language" : "Tuvasta keel",
    "Translation failed" : "Tõlkimine ebaõnnestus",
    "Undo" : "Tühista",
    "Headings" : "Pealkirjad",
    "Info" : "Info",
    "Warning" : "Hoiatus",
    "Edit" : "Redigeeri",
    "Unsupported image type" : "Pildi tüüp pole toetatud"
},
"nplurals=2; plural=(n != 1);");
